#!/bin/sh
# Creates ext2_iflags.h
# I wrote this because the C preprocessor isn't powerful enough to do it.
# "Rerolling the loop" in this way should make it easier (?) and safer
# to edit.
#

SCRIPTNAME=ext2_iflags.sh
DEST=ext2_iflags.h

cat > "$DEST" <<+
/*
 * This file automatically generated by ${SCRIPTNAME}.
 * To make changes, either change ${SCRIPTNAME} and rerun it,
 * or make the changes to this file and delete ${SCRIPTNAME}.
 */

#include <linux/ext2_fs.h>

/* 
 * The ext2fs library private definition of the ext2 inode flag bits,
 * so we don't have to depend on the kernel's definition of the flag
 * bits, which might not have the latest features.
 */

#define	EXT2FS_SECRM_FL		0x00000001 /* Secure deletion */
#define	EXT2FS_UNRM_FL		0x00000002 /* Undelete */
#define	EXT2FS_COMPR_FL		0x00000004 /* Compress file */
#define EXT2FS_SYNC_FL		0x00000008 /* Synchronous updates */
#define EXT2FS_IMMUTABLE_FL	0x00000010 /* Immutable file */
#define EXT2FS_APPEND_FL	0x00000020 /* writes to file may only append */
#define EXT2FS_NODUMP_FL	0x00000040 /* do not dump file */
#define EXT2FS_NOATIME_FL	0x00000080 /* do not update atime */
#define EXT2FS_DIRTY_FL		0x00000100 /* Needs decompressing. */
#define EXT2FS_COMPRBLK_FL	0x00000200 /* One or more compressed clusters. */
#define EXT2FS_NOCOMPR_FL 	0x00000400 /* Access raw compressed data. */
#define EXT2FS_ECOMPR_FL 	0x00000800 /* Compression error */

/*
 * Check for incompatibilities. 
 */
+
for i in SECRM UNRM COMPR SYNC IMMUTABLE APPEND NODUMP NOATIME \
	DIRTY COMPRBLK NOCOMPR ECOMPR \
; do
cat >> "$DEST" <<+

#ifdef EXT2_${i}_FL
# if EXT2_${i}_FL != EXT2FS_${i}_FL
#  error "This kernel using a non-standard value of EXT2_${i}_FL"
# endif
#endif
+
done
